==> osidb_bindings-4.1.1-py3-none-any.whl: osidb_bindings/bindings/python_client/models/exploits_api_v1_report_date_retrieve_response_200_action_required_item.py <==
from typing import Any, Dict, List, Type, TypeVar

import attr

from ..types import OSIDBModel

T = TypeVar("T", bound="ExploitsApiV1ReportDateRetrieveResponse200ActionRequiredItem")


@attr.s(auto_attribs=True)
class ExploitsApiV1ReportDateRetrieveResponse200ActionRequiredItem(OSIDBModel):
    """ """

    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        exploits_api_v1_report_date_retrieve_response_200_action_required_item = cls()

        exploits_api_v1_report_date_retrieve_response_200_action_required_item.additional_properties = (
            d
        )
        return exploits_api_v1_report_date_retrieve_response_200_action_required_item

    @staticmethod
    def get_fields():
        return {}

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> osidb_bindings-4.10.1-py3-none-any.whl: osidb_bindings/bindings/python_client/models/exploits_api_v1_report_date_retrieve_response_200_action_required_item.py <==
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import OSIDBModel

T = TypeVar("T", bound="ExploitsApiV1ReportDateRetrieveResponse200ActionRequiredItem")


@_attrs_define
class ExploitsApiV1ReportDateRetrieveResponse200ActionRequiredItem(OSIDBModel):
    """ """

    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
        d = src_dict.copy()
        exploits_api_v1_report_date_retrieve_response_200_action_required_item = cls()

        exploits_api_v1_report_date_retrieve_response_200_action_required_item.additional_properties = d
        return exploits_api_v1_report_date_retrieve_response_200_action_required_item

    @staticmethod
    def get_fields():
        return {}

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
